@@ -104,6 +104,9 @@ sub outtemplate {
 sub site_addresses {
 	# Looks up the site's main addresses; those that have a default
 	# route.
+	if ($config{hardcode_ipv4} && $config{hardcode_ipv6}) {
+		return ($config{hardcode_ipv4}, $config{hardcode_ipv6});
+	}
 	my ($defiface) = `ip route` =~ m/^default via .* dev ([a-zA-Z0-9]+)/m;
 	if (! $defiface) {
 		# Maybe ipv6 only.
@@ -115,6 +118,12 @@ sub site_addresses {
 	my $show=`ip addr show $defiface`;
 	my ($ipv4) = $show =~ m/inet (\d+\.\d+\.\d+\.\d+).*scope global/m;
 	my ($ipv6) = $show =~ m/inet6 ([a-zA-Z0-9:]+).*scope global/m;
+	if ($config{hardcode_ipv4}) {
+		$ipv4 = $config{hardcode_ipv4};
+	}
+	if ($config{hardcode_ipv6}) {
+		$ipv6 = $config{hardcode_ipv6};
+	}
 	return ($ipv4, $ipv6);
 }
 
